@@ -67,7 +67,7 @@ $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularrat
 toil genstar solvestar integratebox filterbox__ clean
 );
 
-$VERSION = '0.173';
+$VERSION = '0.179';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
@@ -1168,6 +1168,86 @@ sub takewinning
 }
 
 
+sub sense
+{
+	say $tee "WORKING.";
+	my ( $addr, $mypath, $objcolumn, $stopcondition ) = @_;
+	say $tee "IN SENSE \$addr: " . dump( $addr );
+	say $tee "IN SENSE \$mypath: " . dump( $mypath );
+	say $tee "IN SENSE \$objcolumn: " . dump( $objcolumn );
+	say $tee "IN SENSE \$stopcondition: " . dump( $stopcondition );
+
+	my $newaddr = "$mypath/$addr" . "_variances.csv"; say $tee "IN SENSE \$newaddr: " . dump( $newaddr );
+
+	open( ADDR, "$addr" ) or die;
+	my @lines = <ADDR>;
+	close ADDR;
+
+	my @purelines;
+	foreach my $line ( @lines )
+	{
+		chomp $line;
+		push( @purelines, $line );
+	}
+
+	#say $tee "IN SENSE \@lines: " . dump( @lines );
+
+	my @values = map { ( split( ',', $_ ))[ $objcolumn ] } @purelines; say $tee "IN SENSE \@values: " . dump( @values );
+	my $totvariance = variance( @values ); say $tee "IN SENSE \$totvariance: $totvariance" ;
+
+	my @cases = map { ( split( ',', $_ ))[0] } @purelines; say $tee "IN SENSE \@cases: " . dump( @cases );
+
+	my @sack;
+	foreach my $case ( @cases )
+	{
+		my @row = split( "_", $case );
+		push( @sack, [ @row ] );
+	} say $tee "IN SENSE \@sack: " . dump( @sack );
+
+	my %whole;
+	my $count = 0;
+	foreach my $case ( @sack )
+	{
+		my @temp;
+		foreach my $pair ( @{ $case } )
+		{
+			my ( $key, $value ) = split( "-", $pair );
+			push( @{ $whole{$key}{$value} }, $values[$count] );
+		}
+		$count++;
+	} say $tee "IN SENSE \%whole: " . dump( \%whole );
+
+	my ( %sensfs, %avgsensfs );
+	say $tee "IN SENSE keys \%whole: " . dump( keys %whole );
+	foreach my $factor ( keys %whole )
+	{
+		say $tee "IN SENSE \$factor: " . dump( $factor );
+		my @avgvar; say $tee "IN SENSE keys %{ \$whole{\$factor} }: " . dump( keys %{ $whole{$factor} } );
+		foreach my $level ( keys %{ $whole{$factor} } )
+		{
+			say $tee "IN SENSE \$level: " . dump( $level );
+			my $variance = variance( @{ $whole{$factor}{$level} } ); say $tee "IN SENSE \$variance: $variance" ;
+			my $variancerat = ( $variance / $totvariance ); say $tee "IN SENSE \$variancerat: $variancerat" ;
+			$sensfs{$factor}{$level} = $variancerat;
+			push( @avgsensf, $variancerat );
+		}
+		my $mean = mean( @avgsensf );
+		$avgsensfs{$factor} = $mean; say $tee "IN SENSE \$mean: " . dump( $mean );
+	} say $tee "IN SENSE \%sensfs: " . dump( \%sensfs ); say $tee "IN SENSE \%avgsensfs: " . dump( \%avgsensfs );
+
+	open( NEWADDR, ">$newaddr" ) or die;
+	foreach my $fact ( sort{ $a <=> $b }( keys %avgsensfs ) )
+	{
+		say NEWADDR "$fact: $avgsensfs{$fact}";
+	}
+	close NEWADDR;
+	if ( $stopcondition eq "stop" )
+	{
+		exit;
+	}
+}
+
+
 sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 {
 	my %d = %{ $_[0] };
@@ -1189,6 +1269,10 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 
 	if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
   {
+		if ( $dirfiles{checksensitivity} eq "yes" )
+		{
+			Sim::OPT::sense( $dirfiles{ordtot}, $mypath, $dirfiles{objectivecolumn} );
+		}
     exit(say $tee "#END RUN.");
   }
 
@@ -1595,7 +1679,7 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 		#say $tee "IN SETLAUNCH \%inst" . dump( \%inst );
 
 
-		unless( ( $to{cleanto} ~~ @{ $dirfiles{dones} } ) and ( $dirfiles{precomputed} eq "" ))
+		unless( ( $to{cleanto} ~~ @{ $dirfiles{dones} } ) and ( $dirfiles{precomputed} eq "" ) )
 		{
 			push( @{ $dirfiles{dones} }, $to{cleanto} );
 			$inst{$to{cleanto}} = $to{crypto};
@@ -1848,6 +1932,12 @@ sub opt
 	$dowhat{file} = $file;
 	#say $tee "IN OPT \%vals " . dump( %vals );
 
+	if ( $dowhat{justchecksensitivity} ne "" )
+	{
+		say "RECEIVED.";
+		Sim::OPT::sense( $dowhat{justchecksensitivity}, $mypath, $dowhat{objectivecolumn}, "stop" );
+	}
+
   if ( $dowhat{randomsweeps} eq "yes" ) #IT SHUFFLES  @sweeps UNDER REQUESTED SETTING.
   {
     my @newsweeps;
@@ -2022,6 +2112,7 @@ sub opt
 	}
 	elsif ( $target eq "opt" )
 	{
+
 		if ( scalar( @miditers ) == 0 ) { calcmiditers( @varnumbers ); }
 		#$itersnum = getitersnum($countcase, $varnumber, @varnumbers);
 
@@ -2155,7 +2246,10 @@ sub opt
 
 			my @winneritems = populatewinners( \@rootnames, $countcase, $countblock ); #say $tee "\@winneritems: " . dump ( @winneritems );
 
-			my $count = 0;
+			my $count = 0;if ( $dirfiles{justchecksensitivity} eq "yes" )
+{
+  Sim::OPT::sense( $dirfiles{justchecksensitivity}, $mypath, $dirfiles{objectivecolumn} );
+}
 			my @arr;
 			foreach ( @varnumbers )
 			{
@@ -2231,6 +2325,7 @@ Sim::OPT can perform one or more star (Jacoby) searches within blocks in place o
 
 For specifying in a Sim::OPT configuration file that a certain block has to be searched by the means of a metamodel derived from star searches and not by the means of a multilevel full-factorial search it is necessary (once asked for one or more star searches in the block) to assign to < $dowhat{metamodel} > the value "yes" in the configuration file.
 
+Sim::OPT can perform both variance-based sensitivity analyses on the basis of simulated dataseries and preliminary sensitivity analyses based on metamodels.
 
 OPT works under Linux.
 
@@ -2240,7 +2335,7 @@ OPT works under Linux.
 
 =head1 SEE ALSO
 
-Annotated examples ("esp.pl" for ESP-r, "ep.pl" for EnergyPlus - the two perform the same morphing operations on models describing the same building -, "des.pl" about block search, and "f.pl" about a search in a pre-simulated dataset, and other) can be found packed in the "optw.tar.gz" file in "examples" directory in this distribution. They constitute all the available documentation besides these pages. For more information, reference to the source code should be made.
+Annotated examples (which include "esp.pl" for ESP-r, "ep.pl" for EnergyPlus - the two perform the same morphing operations on models describing the same building -, "des.pl" about block search, and "f.pl" about a search in a pre-simulated dataset, and other) can be found packed in the "optw.tar.gz" file in "examples" directory in this distribution. They constitute all the available documentation besides these pages. For more information, reference to the source code should be made.
 
 =head1 AUTHOR
 
